# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from envoy.service.discovery.v3 import discovery_pb2 as envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2


class ExtensionConfigDiscoveryServiceStub(object):
    """[#protodoc-title: Extension config discovery service (ECDS)]

    A service that supports dynamic configuration updates for a specific filter.
    Currently, ECDS is supported for HTTP filters and Listener filters. Please check
    :ref:`Extension Config Discovery Service (ECDS) API <config_overview_extension_discovery>`.
    The overall extension config discovery service works as follows:

    1. A filter (:ref:`Listener <envoy_v3_api_field_config.listener.v3.ListenerFilter.config_discovery>`
    or :ref:`HTTP <envoy_v3_api_field_extensions.filters.network.http_connection_manager.v3.HttpFilter.config_discovery>`)
    contains a :ref:`config_discovery <envoy_v3_api_msg_config.core.v3.ExtensionConfigSource>` configuration. This configuration
    includes a :ref:`config_source <envoy_v3_api_field_config.core.v3.ExtensionConfigSource.config_source>`,
    from which the filter configuration will be fetched.
    2. The client then registers for a resource using the filter name as the resource_name.
    3. The xDS server sends back the filter's configuration.
    4. The client stores the configuration that will be used in the next instantiation of the filter chain,
    i.e., for the next requests. Whenever an updated filter configuration arrives, it will be taken into
    account in the following instantiation of the filter chain.

    Note: Filters that are configured using ECDS are warmed. For more details see
    :ref:`ExtensionConfigSource <envoy_v3_api_msg_config.core.v3.ExtensionConfigSource>`.

    Return extension configurations.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StreamExtensionConfigs = channel.stream_stream(
                '/envoy.service.extension.v3.ExtensionConfigDiscoveryService/StreamExtensionConfigs',
                request_serializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryRequest.SerializeToString,
                response_deserializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryResponse.FromString,
                )
        self.DeltaExtensionConfigs = channel.stream_stream(
                '/envoy.service.extension.v3.ExtensionConfigDiscoveryService/DeltaExtensionConfigs',
                request_serializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DeltaDiscoveryRequest.SerializeToString,
                response_deserializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DeltaDiscoveryResponse.FromString,
                )
        self.FetchExtensionConfigs = channel.unary_unary(
                '/envoy.service.extension.v3.ExtensionConfigDiscoveryService/FetchExtensionConfigs',
                request_serializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryRequest.SerializeToString,
                response_deserializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryResponse.FromString,
                )


class ExtensionConfigDiscoveryServiceServicer(object):
    """[#protodoc-title: Extension config discovery service (ECDS)]

    A service that supports dynamic configuration updates for a specific filter.
    Currently, ECDS is supported for HTTP filters and Listener filters. Please check
    :ref:`Extension Config Discovery Service (ECDS) API <config_overview_extension_discovery>`.
    The overall extension config discovery service works as follows:

    1. A filter (:ref:`Listener <envoy_v3_api_field_config.listener.v3.ListenerFilter.config_discovery>`
    or :ref:`HTTP <envoy_v3_api_field_extensions.filters.network.http_connection_manager.v3.HttpFilter.config_discovery>`)
    contains a :ref:`config_discovery <envoy_v3_api_msg_config.core.v3.ExtensionConfigSource>` configuration. This configuration
    includes a :ref:`config_source <envoy_v3_api_field_config.core.v3.ExtensionConfigSource.config_source>`,
    from which the filter configuration will be fetched.
    2. The client then registers for a resource using the filter name as the resource_name.
    3. The xDS server sends back the filter's configuration.
    4. The client stores the configuration that will be used in the next instantiation of the filter chain,
    i.e., for the next requests. Whenever an updated filter configuration arrives, it will be taken into
    account in the following instantiation of the filter chain.

    Note: Filters that are configured using ECDS are warmed. For more details see
    :ref:`ExtensionConfigSource <envoy_v3_api_msg_config.core.v3.ExtensionConfigSource>`.

    Return extension configurations.
    """

    def StreamExtensionConfigs(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeltaExtensionConfigs(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FetchExtensionConfigs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ExtensionConfigDiscoveryServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'StreamExtensionConfigs': grpc.stream_stream_rpc_method_handler(
                    servicer.StreamExtensionConfigs,
                    request_deserializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryRequest.FromString,
                    response_serializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryResponse.SerializeToString,
            ),
            'DeltaExtensionConfigs': grpc.stream_stream_rpc_method_handler(
                    servicer.DeltaExtensionConfigs,
                    request_deserializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DeltaDiscoveryRequest.FromString,
                    response_serializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DeltaDiscoveryResponse.SerializeToString,
            ),
            'FetchExtensionConfigs': grpc.unary_unary_rpc_method_handler(
                    servicer.FetchExtensionConfigs,
                    request_deserializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryRequest.FromString,
                    response_serializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'envoy.service.extension.v3.ExtensionConfigDiscoveryService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ExtensionConfigDiscoveryService(object):
    """[#protodoc-title: Extension config discovery service (ECDS)]

    A service that supports dynamic configuration updates for a specific filter.
    Currently, ECDS is supported for HTTP filters and Listener filters. Please check
    :ref:`Extension Config Discovery Service (ECDS) API <config_overview_extension_discovery>`.
    The overall extension config discovery service works as follows:

    1. A filter (:ref:`Listener <envoy_v3_api_field_config.listener.v3.ListenerFilter.config_discovery>`
    or :ref:`HTTP <envoy_v3_api_field_extensions.filters.network.http_connection_manager.v3.HttpFilter.config_discovery>`)
    contains a :ref:`config_discovery <envoy_v3_api_msg_config.core.v3.ExtensionConfigSource>` configuration. This configuration
    includes a :ref:`config_source <envoy_v3_api_field_config.core.v3.ExtensionConfigSource.config_source>`,
    from which the filter configuration will be fetched.
    2. The client then registers for a resource using the filter name as the resource_name.
    3. The xDS server sends back the filter's configuration.
    4. The client stores the configuration that will be used in the next instantiation of the filter chain,
    i.e., for the next requests. Whenever an updated filter configuration arrives, it will be taken into
    account in the following instantiation of the filter chain.

    Note: Filters that are configured using ECDS are warmed. For more details see
    :ref:`ExtensionConfigSource <envoy_v3_api_msg_config.core.v3.ExtensionConfigSource>`.

    Return extension configurations.
    """

    @staticmethod
    def StreamExtensionConfigs(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/envoy.service.extension.v3.ExtensionConfigDiscoveryService/StreamExtensionConfigs',
            envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryRequest.SerializeToString,
            envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeltaExtensionConfigs(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/envoy.service.extension.v3.ExtensionConfigDiscoveryService/DeltaExtensionConfigs',
            envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DeltaDiscoveryRequest.SerializeToString,
            envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DeltaDiscoveryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FetchExtensionConfigs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/envoy.service.extension.v3.ExtensionConfigDiscoveryService/FetchExtensionConfigs',
            envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryRequest.SerializeToString,
            envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: xds/annotations/v3/migrate.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n xds/annotations/v3/migrate.proto\x12\x12xds.annotations.v3\x1a google/protobuf/descriptor.proto\"#\n\x11MigrateAnnotation\x12\x0e\n\x06rename\x18\x01 \x01(\t\"A\n\x16\x46ieldMigrateAnnotation\x12\x0e\n\x06rename\x18\x01 \x01(\t\x12\x17\n\x0foneof_promotion\x18\x02 \x01(\t\"0\n\x15\x46ileMigrateAnnotation\x12\x17\n\x0fmove_to_package\x18\x02 \x01(\t:b\n\x0fmessage_migrate\x12\x1f.google.protobuf.MessageOptions\x18\xce\xe9\xed\x35 \x01(\x0b\x32%.xds.annotations.v3.MigrateAnnotation:c\n\rfield_migrate\x12\x1d.google.protobuf.FieldOptions\x18\xce\xe9\xed\x35 \x01(\x0b\x32*.xds.annotations.v3.FieldMigrateAnnotation:\\\n\x0c\x65num_migrate\x12\x1c.google.protobuf.EnumOptions\x18\xce\xe9\xed\x35 \x01(\x0b\x32%.xds.annotations.v3.MigrateAnnotation:g\n\x12\x65num_value_migrate\x12!.google.protobuf.EnumValueOptions\x18\xce\xe9\xed\x35 \x01(\x0b\x32%.xds.annotations.v3.MigrateAnnotation:`\n\x0c\x66ile_migrate\x12\x1c.google.protobuf.FileOptions\x18\xce\xe9\xed\x35 \x01(\x0b\x32).xds.annotations.v3.FileMigrateAnnotationB+Z)github.com/cncf/xds/go/xds/annotations/v3b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xds.annotations.v3.migrate_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(message_migrate)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(field_migrate)
  google_dot_protobuf_dot_descriptor__pb2.EnumOptions.RegisterExtension(enum_migrate)
  google_dot_protobuf_dot_descriptor__pb2.EnumValueOptions.RegisterExtension(enum_value_migrate)
  google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(file_migrate)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z)github.com/cncf/xds/go/xds/annotations/v3'
  _globals['_MIGRATEANNOTATION']._serialized_start=90
  _globals['_MIGRATEANNOTATION']._serialized_end=125
  _globals['_FIELDMIGRATEANNOTATION']._serialized_start=127
  _globals['_FIELDMIGRATEANNOTATION']._serialized_end=192
  _globals['_FILEMIGRATEANNOTATION']._serialized_start=194
  _globals['_FILEMIGRATEANNOTATION']._serialized_end=242
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: xds/type/v3/cel.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api.expr.v1alpha1 import checked_pb2 as google_dot_api_dot_expr_dot_v1alpha1_dot_checked__pb2
from google.api.expr.v1alpha1 import syntax_pb2 as google_dot_api_dot_expr_dot_v1alpha1_dot_syntax__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15xds/type/v3/cel.proto\x12\x0bxds.type.v3\x1a&google/api/expr/v1alpha1/checked.proto\x1a%google/api/expr/v1alpha1/syntax.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fxds/annotations/v3/status.proto\x1a\x17validate/validate.proto\"\xa2\x01\n\rCelExpression\x12;\n\x0bparsed_expr\x18\x01 \x01(\x0b\x32$.google.api.expr.v1alpha1.ParsedExprH\x00\x12=\n\x0c\x63hecked_expr\x18\x02 \x01(\x0b\x32%.google.api.expr.v1alpha1.CheckedExprH\x00\x42\x15\n\x0e\x65xpr_specifier\x12\x03\xf8\x42\x01\"\x83\x01\n\x10\x43\x65lExtractString\x12:\n\x0c\x65xpr_extract\x18\x01 \x01(\x0b\x32\x1a.xds.type.v3.CelExpressionB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x33\n\rdefault_value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueBP\n\x16\x63om.github.xds.type.v3B\x08\x43\x65lProtoP\x01Z\"github.com/cncf/xds/go/xds/type/v3\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xds.type.v3.cel_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.github.xds.type.v3B\010CelProtoP\001Z\"github.com/cncf/xds/go/xds/type/v3\322\306\244\341\006\002\010\001'
  _CELEXPRESSION.oneofs_by_name['expr_specifier']._options = None
  _CELEXPRESSION.oneofs_by_name['expr_specifier']._serialized_options = b'\370B\001'
  _CELEXTRACTSTRING.fields_by_name['expr_extract']._options = None
  _CELEXTRACTSTRING.fields_by_name['expr_extract']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_CELEXPRESSION']._serialized_start=208
  _globals['_CELEXPRESSION']._serialized_end=370
  _globals['_CELEXTRACTSTRING']._serialized_start=373
  _globals['_CELEXTRACTSTRING']._serialized_end=504
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/network/tcp_proxy/v2/tcp_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.config.filter.accesslog.v2 import accesslog_pb2 as envoy_dot_config_dot_filter_dot_accesslog_dot_v2_dot_accesslog__pb2
from envoy.type import hash_policy_pb2 as envoy_dot_type_dot_hash__policy__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8envoy/config/filter/network/tcp_proxy/v2/tcp_proxy.proto\x12(envoy.config.filter.network.tcp_proxy.v2\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x30\x65nvoy/config/filter/accesslog/v2/accesslog.proto\x1a\x1c\x65nvoy/type/hash_policy.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xf1\n\n\x08TcpProxy\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x11\n\x07\x63luster\x18\x02 \x01(\tH\x00\x12_\n\x11weighted_clusters\x18\n \x01(\x0b\x32\x42.envoy.config.filter.network.tcp_proxy.v2.TcpProxy.WeightedClusterH\x00\x12\x33\n\x0emetadata_match\x18\t \x01(\x0b\x32\x1b.envoy.api.v2.core.Metadata\x12/\n\x0cidle_timeout\x18\x08 \x01(\x0b\x32\x19.google.protobuf.Duration\x12:\n\x17\x64ownstream_idle_timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x38\n\x15upstream_idle_timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12?\n\naccess_log\x18\x05 \x03(\x0b\x32+.envoy.config.filter.accesslog.v2.AccessLog\x12Z\n\rdeprecated_v1\x18\x06 \x01(\x0b\x32?.envoy.config.filter.network.tcp_proxy.v2.TcpProxy.DeprecatedV1B\x02\x18\x01\x12\x43\n\x14max_connect_attempts\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x12\x35\n\x0bhash_policy\x18\x0b \x03(\x0b\x32\x16.envoy.type.HashPolicyB\x08\xfa\x42\x05\x92\x01\x02\x10\x01\x12\\\n\x10tunneling_config\x18\x0c \x01(\x0b\x32\x42.envoy.config.filter.network.tcp_proxy.v2.TcpProxy.TunnelingConfig\x1a\xbf\x02\n\x0c\x44\x65precatedV1\x12\x62\n\x06routes\x18\x01 \x03(\x0b\x32H.envoy.config.filter.network.tcp_proxy.v2.TcpProxy.DeprecatedV1.TCPRouteB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\xc6\x01\n\x08TCPRoute\x12\x18\n\x07\x63luster\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x39\n\x13\x64\x65stination_ip_list\x18\x02 \x03(\x0b\x32\x1c.envoy.api.v2.core.CidrRange\x12\x19\n\x11\x64\x65stination_ports\x18\x03 \x01(\t\x12\x34\n\x0esource_ip_list\x18\x04 \x03(\x0b\x32\x1c.envoy.api.v2.core.CidrRange\x12\x14\n\x0csource_ports\x18\x05 \x01(\t:\x02\x18\x01\x1a\xf5\x01\n\x0fWeightedCluster\x12l\n\x08\x63lusters\x18\x01 \x03(\x0b\x32P.envoy.config.filter.network.tcp_proxy.v2.TcpProxy.WeightedCluster.ClusterWeightB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1at\n\rClusterWeight\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x17\n\x06weight\x18\x02 \x01(\rB\x07\xfa\x42\x04*\x02(\x01\x12\x33\n\x0emetadata_match\x18\x03 \x01(\x0b\x32\x1b.envoy.api.v2.core.Metadata\x1a,\n\x0fTunnelingConfig\x12\x19\n\x08hostname\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x42\x18\n\x11\x63luster_specifier\x12\x03\xf8\x42\x01\x42\xe3\x01\n6io.envoyproxy.envoy.config.filter.network.tcp_proxy.v2B\rTcpProxyProtoP\x01Z[github.com/envoyproxy/go-control-plane/envoy/config/filter/network/tcp_proxy/v2;tcp_proxyv2\xf2\x98\xfe\x8f\x05/\x12-envoy.extensions.filters.network.tcp_proxy.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.network.tcp_proxy.v2.tcp_proxy_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n6io.envoyproxy.envoy.config.filter.network.tcp_proxy.v2B\rTcpProxyProtoP\001Z[github.com/envoyproxy/go-control-plane/envoy/config/filter/network/tcp_proxy/v2;tcp_proxyv2\362\230\376\217\005/\022-envoy.extensions.filters.network.tcp_proxy.v3\272\200\310\321\006\002\020\001'
  _TCPPROXY_DEPRECATEDV1_TCPROUTE.fields_by_name['cluster']._options = None
  _TCPPROXY_DEPRECATEDV1_TCPROUTE.fields_by_name['cluster']._serialized_options = b'\372B\004r\002 \001'
  _TCPPROXY_DEPRECATEDV1.fields_by_name['routes']._options = None
  _TCPPROXY_DEPRECATEDV1.fields_by_name['routes']._serialized_options = b'\372B\005\222\001\002\010\001'
  _TCPPROXY_DEPRECATEDV1._options = None
  _TCPPROXY_DEPRECATEDV1._serialized_options = b'\030\001'
  _TCPPROXY_WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['name']._options = None
  _TCPPROXY_WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _TCPPROXY_WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['weight']._options = None
  _TCPPROXY_WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['weight']._serialized_options = b'\372B\004*\002(\001'
  _TCPPROXY_WEIGHTEDCLUSTER.fields_by_name['clusters']._options = None
  _TCPPROXY_WEIGHTEDCLUSTER.fields_by_name['clusters']._serialized_options = b'\372B\005\222\001\002\010\001'
  _TCPPROXY_TUNNELINGCONFIG.fields_by_name['hostname']._options = None
  _TCPPROXY_TUNNELINGCONFIG.fields_by_name['hostname']._serialized_options = b'\372B\004r\002 \001'
  _TCPPROXY.oneofs_by_name['cluster_specifier']._options = None
  _TCPPROXY.oneofs_by_name['cluster_specifier']._serialized_options = b'\370B\001'
  _TCPPROXY.fields_by_name['stat_prefix']._options = None
  _TCPPROXY.fields_by_name['stat_prefix']._serialized_options = b'\372B\004r\002 \001'
  _TCPPROXY.fields_by_name['deprecated_v1']._options = None
  _TCPPROXY.fields_by_name['deprecated_v1']._serialized_options = b'\030\001'
  _TCPPROXY.fields_by_name['max_connect_attempts']._options = None
  _TCPPROXY.fields_by_name['max_connect_attempts']._serialized_options = b'\372B\004*\002(\001'
  _TCPPROXY.fields_by_name['hash_policy']._options = None
  _TCPPROXY.fields_by_name['hash_policy']._serialized_options = b'\372B\005\222\001\002\020\001'
  _globals['_TCPPROXY']._serialized_start=398
  _globals['_TCPPROXY']._serialized_end=1791
  _globals['_TCPPROXY_DEPRECATEDV1']._serialized_start=1152
  _globals['_TCPPROXY_DEPRECATEDV1']._serialized_end=1471
  _globals['_TCPPROXY_DEPRECATEDV1_TCPROUTE']._serialized_start=1269
  _globals['_TCPPROXY_DEPRECATEDV1_TCPROUTE']._serialized_end=1467
  _globals['_TCPPROXY_WEIGHTEDCLUSTER']._serialized_start=1474
  _globals['_TCPPROXY_WEIGHTEDCLUSTER']._serialized_end=1719
  _globals['_TCPPROXY_WEIGHTEDCLUSTER_CLUSTERWEIGHT']._serialized_start=1603
  _globals['_TCPPROXY_WEIGHTEDCLUSTER_CLUSTERWEIGHT']._serialized_end=1719
  _globals['_TCPPROXY_TUNNELINGCONFIG']._serialized_start=1721
  _globals['_TCPPROXY_TUNNELINGCONFIG']._serialized_end=1765
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/load_balancing_policies/wrr_locality/v3/wrr_locality.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.cluster.v3 import cluster_pb2 as envoy_dot_config_dot_cluster_dot_v3_dot_cluster__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKenvoy/extensions/load_balancing_policies/wrr_locality/v3/wrr_locality.proto\x12\x38\x65nvoy.extensions.load_balancing_policies.wrr_locality.v3\x1a%envoy/config/cluster/v3/cluster.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"f\n\x0bWrrLocality\x12W\n\x17\x65ndpoint_picking_policy\x18\x01 \x01(\x0b\x32,.envoy.config.cluster.v3.LoadBalancingPolicyB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x42\xd4\x01\nFio.envoyproxy.envoy.extensions.load_balancing_policies.wrr_locality.v3B\x10WrrLocalityProtoP\x01Zngithub.com/envoyproxy/go-control-plane/envoy/extensions/load_balancing_policies/wrr_locality/v3;wrr_localityv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.load_balancing_policies.wrr_locality.v3.wrr_locality_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nFio.envoyproxy.envoy.extensions.load_balancing_policies.wrr_locality.v3B\020WrrLocalityProtoP\001Zngithub.com/envoyproxy/go-control-plane/envoy/extensions/load_balancing_policies/wrr_locality/v3;wrr_localityv3\272\200\310\321\006\002\020\002'
  _WRRLOCALITY.fields_by_name['endpoint_picking_policy']._options = None
  _WRRLOCALITY.fields_by_name['endpoint_picking_policy']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_WRRLOCALITY']._serialized_start=232
  _globals['_WRRLOCALITY']._serialized_end=334
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencensus/proto/agent/metrics/v1/metrics_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opencensus.proto.agent.common.v1 import common_pb2 as opencensus_dot_proto_dot_agent_dot_common_dot_v1_dot_common__pb2
from opencensus.proto.metrics.v1 import metrics_pb2 as opencensus_dot_proto_dot_metrics_dot_v1_dot_metrics__pb2
from opencensus.proto.resource.v1 import resource_pb2 as opencensus_dot_proto_dot_resource_dot_v1_dot_resource__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7opencensus/proto/agent/metrics/v1/metrics_service.proto\x12!opencensus.proto.agent.metrics.v1\x1a-opencensus/proto/agent/common/v1/common.proto\x1a)opencensus/proto/metrics/v1/metrics.proto\x1a+opencensus/proto/resource/v1/resource.proto\"\xc3\x01\n\x1b\x45xportMetricsServiceRequest\x12\x34\n\x04node\x18\x01 \x01(\x0b\x32&.opencensus.proto.agent.common.v1.Node\x12\x34\n\x07metrics\x18\x02 \x03(\x0b\x32#.opencensus.proto.metrics.v1.Metric\x12\x38\n\x08resource\x18\x03 \x01(\x0b\x32&.opencensus.proto.resource.v1.Resource\"\x1e\n\x1c\x45xportMetricsServiceResponse2\xa2\x01\n\x0eMetricsService\x12\x8f\x01\n\x06\x45xport\x12>.opencensus.proto.agent.metrics.v1.ExportMetricsServiceRequest\x1a?.opencensus.proto.agent.metrics.v1.ExportMetricsServiceResponse\"\x00(\x01\x30\x01\x42\xad\x01\n$io.opencensus.proto.agent.metrics.v1B\x13MetricsServiceProtoP\x01ZJgithub.com/census-instrumentation/opencensus-proto/gen-go/agent/metrics/v1\xea\x02!OpenCensus.Proto.Agent.Metrics.V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'opencensus.proto.agent.metrics.v1.metrics_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$io.opencensus.proto.agent.metrics.v1B\023MetricsServiceProtoP\001ZJgithub.com/census-instrumentation/opencensus-proto/gen-go/agent/metrics/v1\352\002!OpenCensus.Proto.Agent.Metrics.V1'
  _globals['_EXPORTMETRICSSERVICEREQUEST']._serialized_start=230
  _globals['_EXPORTMETRICSSERVICEREQUEST']._serialized_end=425
  _globals['_EXPORTMETRICSSERVICERESPONSE']._serialized_start=427
  _globals['_EXPORTMETRICSSERVICERESPONSE']._serialized_end=457
  _globals['_METRICSSERVICE']._serialized_start=460
  _globals['_METRICSSERVICE']._serialized_end=622
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from envoy.service.discovery.v3 import discovery_pb2 as envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2


class RuntimeDiscoveryServiceStub(object):
    """[#protodoc-title: Runtime discovery service (RTDS)]
    RTDS :ref:`configuration overview <config_runtime_rtds>`

    Discovery service for Runtime resources.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StreamRuntime = channel.stream_stream(
                '/envoy.service.runtime.v3.RuntimeDiscoveryService/StreamRuntime',
                request_serializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryRequest.SerializeToString,
                response_deserializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryResponse.FromString,
                )
        self.DeltaRuntime = channel.stream_stream(
                '/envoy.service.runtime.v3.RuntimeDiscoveryService/DeltaRuntime',
                request_serializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DeltaDiscoveryRequest.SerializeToString,
                response_deserializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DeltaDiscoveryResponse.FromString,
                )
        self.FetchRuntime = channel.unary_unary(
                '/envoy.service.runtime.v3.RuntimeDiscoveryService/FetchRuntime',
                request_serializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryRequest.SerializeToString,
                response_deserializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryResponse.FromString,
                )


class RuntimeDiscoveryServiceServicer(object):
    """[#protodoc-title: Runtime discovery service (RTDS)]
    RTDS :ref:`configuration overview <config_runtime_rtds>`

    Discovery service for Runtime resources.
    """

    def StreamRuntime(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeltaRuntime(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FetchRuntime(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RuntimeDiscoveryServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'StreamRuntime': grpc.stream_stream_rpc_method_handler(
                    servicer.StreamRuntime,
                    request_deserializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryRequest.FromString,
                    response_serializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryResponse.SerializeToString,
            ),
            'DeltaRuntime': grpc.stream_stream_rpc_method_handler(
                    servicer.DeltaRuntime,
                    request_deserializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DeltaDiscoveryRequest.FromString,
                    response_serializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DeltaDiscoveryResponse.SerializeToString,
            ),
            'FetchRuntime': grpc.unary_unary_rpc_method_handler(
                    servicer.FetchRuntime,
                    request_deserializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryRequest.FromString,
                    response_serializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'envoy.service.runtime.v3.RuntimeDiscoveryService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RuntimeDiscoveryService(object):
    """[#protodoc-title: Runtime discovery service (RTDS)]
    RTDS :ref:`configuration overview <config_runtime_rtds>`

    Discovery service for Runtime resources.
    """

    @staticmethod
    def StreamRuntime(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/envoy.service.runtime.v3.RuntimeDiscoveryService/StreamRuntime',
            envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryRequest.SerializeToString,
            envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeltaRuntime(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/envoy.service.runtime.v3.RuntimeDiscoveryService/DeltaRuntime',
            envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DeltaDiscoveryRequest.SerializeToString,
            envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DeltaDiscoveryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FetchRuntime(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/envoy.service.runtime.v3.RuntimeDiscoveryService/FetchRuntime',
            envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryRequest.SerializeToString,
            envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/admin/v3/mutex_stats.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n envoy/admin/v3/mutex_stats.proto\x12\x0e\x65nvoy.admin.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"\x87\x01\n\nMutexStats\x12\x17\n\x0fnum_contentions\x18\x01 \x01(\x04\x12\x1b\n\x13\x63urrent_wait_cycles\x18\x02 \x01(\x04\x12\x1c\n\x14lifetime_wait_cycles\x18\x03 \x01(\x04:%\x9a\xc5\x88\x1e \n\x1e\x65nvoy.admin.v2alpha.MutexStatsBx\n\x1cio.envoyproxy.envoy.admin.v3B\x0fMutexStatsProtoP\x01Z=github.com/envoyproxy/go-control-plane/envoy/admin/v3;adminv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.admin.v3.mutex_stats_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034io.envoyproxy.envoy.admin.v3B\017MutexStatsProtoP\001Z=github.com/envoyproxy/go-control-plane/envoy/admin/v3;adminv3\272\200\310\321\006\002\020\002'
  _MUTEXSTATS._options = None
  _MUTEXSTATS._serialized_options = b'\232\305\210\036 \n\036envoy.admin.v2alpha.MutexStats'
  _globals['_MUTEXSTATS']._serialized_start=119
  _globals['_MUTEXSTATS']._serialized_end=254
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/data/accesslog/v2/accesslog.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'envoy/data/accesslog/v2/accesslog.proto\x12\x17\x65nvoy.data.accesslog.v2\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xa6\x01\n\x11TCPAccessLogEntry\x12\x43\n\x11\x63ommon_properties\x18\x01 \x01(\x0b\x32(.envoy.data.accesslog.v2.AccessLogCommon\x12L\n\x15\x63onnection_properties\x18\x02 \x01(\x0b\x32-.envoy.data.accesslog.v2.ConnectionProperties\"\x87\x03\n\x12HTTPAccessLogEntry\x12\x43\n\x11\x63ommon_properties\x18\x01 \x01(\x0b\x32(.envoy.data.accesslog.v2.AccessLogCommon\x12Q\n\x10protocol_version\x18\x02 \x01(\x0e\x32\x37.envoy.data.accesslog.v2.HTTPAccessLogEntry.HTTPVersion\x12?\n\x07request\x18\x03 \x01(\x0b\x32..envoy.data.accesslog.v2.HTTPRequestProperties\x12\x41\n\x08response\x18\x04 \x01(\x0b\x32/.envoy.data.accesslog.v2.HTTPResponseProperties\"U\n\x0bHTTPVersion\x12\x18\n\x14PROTOCOL_UNSPECIFIED\x10\x00\x12\n\n\x06HTTP10\x10\x01\x12\n\n\x06HTTP11\x10\x02\x12\t\n\x05HTTP2\x10\x03\x12\t\n\x05HTTP3\x10\x04\"B\n\x14\x43onnectionProperties\x12\x16\n\x0ereceived_bytes\x18\x01 \x01(\x04\x12\x12\n\nsent_bytes\x18\x02 \x01(\x04\"\xb0\n\n\x0f\x41\x63\x63\x65ssLogCommon\x12,\n\x0bsample_rate\x18\x01 \x01(\x01\x42\x17\xfa\x42\x14\x12\x12\x19\x00\x00\x00\x00\x00\x00\xf0?!\x00\x00\x00\x00\x00\x00\x00\x00\x12=\n\x19\x64ownstream_remote_address\x18\x02 \x01(\x0b\x32\x1a.envoy.api.v2.core.Address\x12<\n\x18\x64ownstream_local_address\x18\x03 \x01(\x0b\x32\x1a.envoy.api.v2.core.Address\x12>\n\x0etls_properties\x18\x04 \x01(\x0b\x32&.envoy.data.accesslog.v2.TLSProperties\x12.\n\nstart_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x37\n\x14time_to_last_rx_byte\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x41\n\x1etime_to_first_upstream_tx_byte\x18\x07 \x01(\x0b\x32\x19.google.protobuf.Duration\x12@\n\x1dtime_to_last_upstream_tx_byte\x18\x08 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x41\n\x1etime_to_first_upstream_rx_byte\x18\t \x01(\x0b\x32\x19.google.protobuf.Duration\x12@\n\x1dtime_to_last_upstream_rx_byte\x18\n \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x43\n time_to_first_downstream_tx_byte\x18\x0b \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x42\n\x1ftime_to_last_downstream_tx_byte\x18\x0c \x01(\x0b\x32\x19.google.protobuf.Duration\x12;\n\x17upstream_remote_address\x18\r \x01(\x0b\x32\x1a.envoy.api.v2.core.Address\x12:\n\x16upstream_local_address\x18\x0e \x01(\x0b\x32\x1a.envoy.api.v2.core.Address\x12\x18\n\x10upstream_cluster\x18\x0f \x01(\t\x12>\n\x0eresponse_flags\x18\x10 \x01(\x0b\x32&.envoy.data.accesslog.v2.ResponseFlags\x12-\n\x08metadata\x18\x11 \x01(\x0b\x32\x1b.envoy.api.v2.core.Metadata\x12)\n!upstream_transport_failure_reason\x18\x12 \x01(\t\x12\x12\n\nroute_name\x18\x13 \x01(\t\x12\x44\n downstream_direct_remote_address\x18\x14 \x01(\x0b\x32\x1a.envoy.api.v2.core.Address\x12^\n\x14\x66ilter_state_objects\x18\x15 \x03(\x0b\x32@.envoy.data.accesslog.v2.AccessLogCommon.FilterStateObjectsEntry\x1aO\n\x17\x46ilterStateObjectsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\x02\x38\x01\"\xae\x06\n\rResponseFlags\x12 \n\x18\x66\x61iled_local_healthcheck\x18\x01 \x01(\x08\x12\x1b\n\x13no_healthy_upstream\x18\x02 \x01(\x08\x12 \n\x18upstream_request_timeout\x18\x03 \x01(\x08\x12\x13\n\x0blocal_reset\x18\x04 \x01(\x08\x12\x1d\n\x15upstream_remote_reset\x18\x05 \x01(\x08\x12#\n\x1bupstream_connection_failure\x18\x06 \x01(\x08\x12\'\n\x1fupstream_connection_termination\x18\x07 \x01(\x08\x12\x19\n\x11upstream_overflow\x18\x08 \x01(\x08\x12\x16\n\x0eno_route_found\x18\t \x01(\x08\x12\x16\n\x0e\x64\x65lay_injected\x18\n \x01(\x08\x12\x16\n\x0e\x66\x61ult_injected\x18\x0b \x01(\x08\x12\x14\n\x0crate_limited\x18\x0c \x01(\x08\x12Q\n\x14unauthorized_details\x18\r \x01(\x0b\x32\x33.envoy.data.accesslog.v2.ResponseFlags.Unauthorized\x12 \n\x18rate_limit_service_error\x18\x0e \x01(\x08\x12)\n!downstream_connection_termination\x18\x0f \x01(\x08\x12%\n\x1dupstream_retry_limit_exceeded\x18\x10 \x01(\x08\x12\x1b\n\x13stream_idle_timeout\x18\x11 \x01(\x08\x12%\n\x1dinvalid_envoy_request_headers\x18\x12 \x01(\x08\x12!\n\x19\x64ownstream_protocol_error\x18\x13 \x01(\x08\x1a\x92\x01\n\x0cUnauthorized\x12J\n\x06reason\x18\x01 \x01(\x0e\x32:.envoy.data.accesslog.v2.ResponseFlags.Unauthorized.Reason\"6\n\x06Reason\x12\x16\n\x12REASON_UNSPECIFIED\x10\x00\x12\x14\n\x10\x45XTERNAL_SERVICE\x10\x01\"\xaa\x05\n\rTLSProperties\x12\x46\n\x0btls_version\x18\x01 \x01(\x0e\x32\x31.envoy.data.accesslog.v2.TLSProperties.TLSVersion\x12\x36\n\x10tls_cipher_suite\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x18\n\x10tls_sni_hostname\x18\x03 \x01(\t\x12\x62\n\x1clocal_certificate_properties\x18\x04 \x01(\x0b\x32<.envoy.data.accesslog.v2.TLSProperties.CertificateProperties\x12\x61\n\x1bpeer_certificate_properties\x18\x05 \x01(\x0b\x32<.envoy.data.accesslog.v2.TLSProperties.CertificateProperties\x12\x16\n\x0etls_session_id\x18\x06 \x01(\t\x1a\xc6\x01\n\x15\x43\x65rtificateProperties\x12\x65\n\x10subject_alt_name\x18\x01 \x03(\x0b\x32K.envoy.data.accesslog.v2.TLSProperties.CertificateProperties.SubjectAltName\x12\x0f\n\x07subject\x18\x02 \x01(\t\x1a\x35\n\x0eSubjectAltName\x12\r\n\x03uri\x18\x01 \x01(\tH\x00\x12\r\n\x03\x64ns\x18\x02 \x01(\tH\x00\x42\x05\n\x03san\"W\n\nTLSVersion\x12\x17\n\x13VERSION_UNSPECIFIED\x10\x00\x12\t\n\x05TLSv1\x10\x01\x12\x0b\n\x07TLSv1_1\x10\x02\x12\x0b\n\x07TLSv1_2\x10\x03\x12\x0b\n\x07TLSv1_3\x10\x04\"\xee\x03\n\x15HTTPRequestProperties\x12\x42\n\x0erequest_method\x18\x01 \x01(\x0e\x32 .envoy.api.v2.core.RequestMethodB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x0e\n\x06scheme\x18\x02 \x01(\t\x12\x11\n\tauthority\x18\x03 \x01(\t\x12*\n\x04port\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x0c\n\x04path\x18\x05 \x01(\t\x12\x12\n\nuser_agent\x18\x06 \x01(\t\x12\x0f\n\x07referer\x18\x07 \x01(\t\x12\x15\n\rforwarded_for\x18\x08 \x01(\t\x12\x12\n\nrequest_id\x18\t \x01(\t\x12\x15\n\roriginal_path\x18\n \x01(\t\x12\x1d\n\x15request_headers_bytes\x18\x0b \x01(\x04\x12\x1a\n\x12request_body_bytes\x18\x0c \x01(\x04\x12[\n\x0frequest_headers\x18\r \x03(\x0b\x32\x42.envoy.data.accesslog.v2.HTTPRequestProperties.RequestHeadersEntry\x1a\x35\n\x13RequestHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xdc\x03\n\x16HTTPResponseProperties\x12\x33\n\rresponse_code\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x1e\n\x16response_headers_bytes\x18\x02 \x01(\x04\x12\x1b\n\x13response_body_bytes\x18\x03 \x01(\x04\x12^\n\x10response_headers\x18\x04 \x03(\x0b\x32\x44.envoy.data.accesslog.v2.HTTPResponseProperties.ResponseHeadersEntry\x12`\n\x11response_trailers\x18\x05 \x03(\x0b\x32\x45.envoy.data.accesslog.v2.HTTPResponseProperties.ResponseTrailersEntry\x12\x1d\n\x15response_code_details\x18\x06 \x01(\t\x1a\x36\n\x14ResponseHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x37\n\x15ResponseTrailersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x8d\x01\n%io.envoyproxy.envoy.data.accesslog.v2B\x0e\x41\x63\x63\x65sslogProtoP\x01ZJgithub.com/envoyproxy/go-control-plane/envoy/data/accesslog/v2;accesslogv2\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.data.accesslog.v2.accesslog_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%io.envoyproxy.envoy.data.accesslog.v2B\016AccesslogProtoP\001ZJgithub.com/envoyproxy/go-control-plane/envoy/data/accesslog/v2;accesslogv2\272\200\310\321\006\002\020\001'
  _ACCESSLOGCOMMON_FILTERSTATEOBJECTSENTRY._options = None
  _ACCESSLOGCOMMON_FILTERSTATEOBJECTSENTRY._serialized_options = b'8\001'
  _ACCESSLOGCOMMON.fields_by_name['sample_rate']._options = None
  _ACCESSLOGCOMMON.fields_by_name['sample_rate']._serialized_options = b'\372B\024\022\022\031\000\000\000\000\000\000\360?!\000\000\000\000\000\000\000\000'
  _HTTPREQUESTPROPERTIES_REQUESTHEADERSENTRY._options = None
  _HTTPREQUESTPROPERTIES_REQUESTHEADERSENTRY._serialized_options = b'8\001'
  _HTTPREQUESTPROPERTIES.fields_by_name['request_method']._options = None
  _HTTPREQUESTPROPERTIES.fields_by_name['request_method']._serialized_options = b'\372B\005\202\001\002\020\001'
  _HTTPRESPONSEPROPERTIES_RESPONSEHEADERSENTRY._options = None
  _HTTPRESPONSEPROPERTIES_RESPONSEHEADERSENTRY._serialized_options = b'8\001'
  _HTTPRESPONSEPROPERTIES_RESPONSETRAILERSENTRY._options = None
  _HTTPRESPONSEPROPERTIES_RESPONSETRAILERSENTRY._serialized_options = b'8\001'
  _globals['_TCPACCESSLOGENTRY']._serialized_start=312
  _globals['_TCPACCESSLOGENTRY']._serialized_end=478
  _globals['_HTTPACCESSLOGENTRY']._serialized_start=481
  _globals['_HTTPACCESSLOGENTRY']._serialized_end=872
  _globals['_HTTPACCESSLOGENTRY_HTTPVERSION']._serialized_start=787
  _globals['_HTTPACCESSLOGENTRY_HTTPVERSION']._serialized_end=872
  _globals['_CONNECTIONPROPERTIES']._serialized_start=874
  _globals['_CONNECTIONPROPERTIES']._serialized_end=940
  _globals['_ACCESSLOGCOMMON']._serialized_start=943
  _globals['_ACCESSLOGCOMMON']._serialized_end=2271
  _globals['_ACCESSLOGCOMMON_FILTERSTATEOBJECTSENTRY']._serialized_start=2192
  _globals['_ACCESSLOGCOMMON_FILTERSTATEOBJECTSENTRY']._serialized_end=2271
  _globals['_RESPONSEFLAGS']._serialized_start=2274
  _globals['_RESPONSEFLAGS']._serialized_end=3088
  _globals['_RESPONSEFLAGS_UNAUTHORIZED']._serialized_start=2942
  _globals['_RESPONSEFLAGS_UNAUTHORIZED']._serialized_end=3088
  _globals['_RESPONSEFLAGS_UNAUTHORIZED_REASON']._serialized_start=3034
  _globals['_RESPONSEFLAGS_UNAUTHORIZED_REASON']._serialized_end=3088
  _globals['_TLSPROPERTIES']._serialized_start=3091
  _globals['_TLSPROPERTIES']._serialized_end=3773
  _globals['_TLSPROPERTIES_CERTIFICATEPROPERTIES']._serialized_start=3486
  _globals['_TLSPROPERTIES_CERTIFICATEPROPERTIES']._serialized_end=3684
  _globals['_TLSPROPERTIES_CERTIFICATEPROPERTIES_SUBJECTALTNAME']._serialized_start=3631
  _globals['_TLSPROPERTIES_CERTIFICATEPROPERTIES_SUBJECTALTNAME']._serialized_end=3684
  _globals['_TLSPROPERTIES_TLSVERSION']._serialized_start=3686
  _globals['_TLSPROPERTIES_TLSVERSION']._serialized_end=3773
  _globals['_HTTPREQUESTPROPERTIES']._serialized_start=3776
  _globals['_HTTPREQUESTPROPERTIES']._serialized_end=4270
  _globals['_HTTPREQUESTPROPERTIES_REQUESTHEADERSENTRY']._serialized_start=4217
  _globals['_HTTPREQUESTPROPERTIES_REQUESTHEADERSENTRY']._serialized_end=4270
  _globals['_HTTPRESPONSEPROPERTIES']._serialized_start=4273
  _globals['_HTTPRESPONSEPROPERTIES']._serialized_end=4749
  _globals['_HTTPRESPONSEPROPERTIES_RESPONSEHEADERSENTRY']._serialized_start=4638
  _globals['_HTTPRESPONSEPROPERTIES_RESPONSEHEADERSENTRY']._serialized_end=4692
  _globals['_HTTPRESPONSEPROPERTIES_RESPONSETRAILERSENTRY']._serialized_start=4694
  _globals['_HTTPRESPONSEPROPERTIES_RESPONSETRAILERSENTRY']._serialized_end=4749
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/common/dependency/v3/dependency.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>envoy/extensions/filters/common/dependency/v3/dependency.proto\x12-envoy.extensions.filters.common.dependency.v3\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xc5\x01\n\nDependency\x12V\n\x04type\x18\x01 \x01(\x0e\x32H.envoy.extensions.filters.common.dependency.v3.Dependency.DependencyType\x12\x15\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"H\n\x0e\x44\x65pendencyType\x12\n\n\x06HEADER\x10\x00\x12\x14\n\x10\x46ILTER_STATE_KEY\x10\x01\x12\x14\n\x10\x44YNAMIC_METADATA\x10\x02\"\xe4\x02\n\x12\x46ilterDependencies\x12R\n\x0f\x64\x65\x63ode_required\x18\x01 \x03(\x0b\x32\x39.envoy.extensions.filters.common.dependency.v3.Dependency\x12R\n\x0f\x64\x65\x63ode_provided\x18\x02 \x03(\x0b\x32\x39.envoy.extensions.filters.common.dependency.v3.Dependency\x12R\n\x0f\x65ncode_required\x18\x03 \x03(\x0b\x32\x39.envoy.extensions.filters.common.dependency.v3.Dependency\x12R\n\x0f\x65ncode_provided\x18\x04 \x03(\x0b\x32\x39.envoy.extensions.filters.common.dependency.v3.Dependency\"\xb5\x01\n\x14MatchingRequirements\x12u\n\x15\x64\x61ta_input_allow_list\x18\x01 \x01(\x0b\x32V.envoy.extensions.filters.common.dependency.v3.MatchingRequirements.DataInputAllowList\x1a&\n\x12\x44\x61taInputAllowList\x12\x10\n\x08type_url\x18\x01 \x03(\tB\xbb\x01\n;io.envoyproxy.envoy.extensions.filters.common.dependency.v3B\x0f\x44\x65pendencyProtoP\x01Zagithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/common/dependency/v3;dependencyv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.common.dependency.v3.dependency_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n;io.envoyproxy.envoy.extensions.filters.common.dependency.v3B\017DependencyProtoP\001Zagithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/common/dependency/v3;dependencyv3\272\200\310\321\006\002\020\002'
  _DEPENDENCY.fields_by_name['name']._options = None
  _DEPENDENCY.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_DEPENDENCY']._serialized_start=170
  _globals['_DEPENDENCY']._serialized_end=367
  _globals['_DEPENDENCY_DEPENDENCYTYPE']._serialized_start=295
  _globals['_DEPENDENCY_DEPENDENCYTYPE']._serialized_end=367
  _globals['_FILTERDEPENDENCIES']._serialized_start=370
  _globals['_FILTERDEPENDENCIES']._serialized_end=726
  _globals['_MATCHINGREQUIREMENTS']._serialized_start=729
  _globals['_MATCHINGREQUIREMENTS']._serialized_end=910
  _globals['_MATCHINGREQUIREMENTS_DATAINPUTALLOWLIST']._serialized_start=872
  _globals['_MATCHINGREQUIREMENTS_DATAINPUTALLOWLIST']._serialized_end=910
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/admin/v3/init_dump.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65nvoy/admin/v3/init_dump.proto\x12\x0e\x65nvoy.admin.v3\x1a\x1dudpa/annotations/status.proto\"\xa6\x01\n\x13UnreadyTargetsDumps\x12U\n\x15unready_targets_dumps\x18\x01 \x03(\x0b\x32\x36.envoy.admin.v3.UnreadyTargetsDumps.UnreadyTargetsDump\x1a\x38\n\x12UnreadyTargetsDump\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0ctarget_names\x18\x02 \x03(\tBv\n\x1cio.envoyproxy.envoy.admin.v3B\rInitDumpProtoP\x01Z=github.com/envoyproxy/go-control-plane/envoy/admin/v3;adminv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.admin.v3.init_dump_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034io.envoyproxy.envoy.admin.v3B\rInitDumpProtoP\001Z=github.com/envoyproxy/go-control-plane/envoy/admin/v3;adminv3\272\200\310\321\006\002\020\002'
  _globals['_UNREADYTARGETSDUMPS']._serialized_start=82
  _globals['_UNREADYTARGETSDUMPS']._serialized_end=248
  _globals['_UNREADYTARGETSDUMPS_UNREADYTARGETSDUMP']._serialized_start=192
  _globals['_UNREADYTARGETSDUMPS_UNREADYTARGETSDUMP']._serialized_end=248
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/matcher/v3/metadata.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.matcher.v3 import value_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_value__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$envoy/type/matcher/v3/metadata.proto\x12\x15\x65nvoy.type.matcher.v3\x1a!envoy/type/matcher/v3/value.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xdd\x02\n\x0fMetadataMatcher\x12\x17\n\x06\x66ilter\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12J\n\x04path\x18\x02 \x03(\x0b\x32\x32.envoy.type.matcher.v3.MetadataMatcher.PathSegmentB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12<\n\x05value\x18\x03 \x01(\x0b\x32#.envoy.type.matcher.v3.ValueMatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x0e\n\x06invert\x18\x04 \x01(\x08\x1al\n\x0bPathSegment\x12\x16\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00:5\x9a\xc5\x88\x1e\x30\n.envoy.type.matcher.MetadataMatcher.PathSegmentB\x0e\n\x07segment\x12\x03\xf8\x42\x01:)\x9a\xc5\x88\x1e$\n\"envoy.type.matcher.MetadataMatcherB\x86\x01\n#io.envoyproxy.envoy.type.matcher.v3B\rMetadataProtoP\x01ZFgithub.com/envoyproxy/go-control-plane/envoy/type/matcher/v3;matcherv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.type.matcher.v3.metadata_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.envoyproxy.envoy.type.matcher.v3B\rMetadataProtoP\001ZFgithub.com/envoyproxy/go-control-plane/envoy/type/matcher/v3;matcherv3\272\200\310\321\006\002\020\002'
  _METADATAMATCHER_PATHSEGMENT.oneofs_by_name['segment']._options = None
  _METADATAMATCHER_PATHSEGMENT.oneofs_by_name['segment']._serialized_options = b'\370B\001'
  _METADATAMATCHER_PATHSEGMENT.fields_by_name['key']._options = None
  _METADATAMATCHER_PATHSEGMENT.fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _METADATAMATCHER_PATHSEGMENT._options = None
  _METADATAMATCHER_PATHSEGMENT._serialized_options = b'\232\305\210\0360\n.envoy.type.matcher.MetadataMatcher.PathSegment'
  _METADATAMATCHER.fields_by_name['filter']._options = None
  _METADATAMATCHER.fields_by_name['filter']._serialized_options = b'\372B\004r\002\020\001'
  _METADATAMATCHER.fields_by_name['path']._options = None
  _METADATAMATCHER.fields_by_name['path']._serialized_options = b'\372B\005\222\001\002\010\001'
  _METADATAMATCHER.fields_by_name['value']._options = None
  _METADATAMATCHER.fields_by_name['value']._serialized_options = b'\372B\005\212\001\002\020\001'
  _METADATAMATCHER._options = None
  _METADATAMATCHER._serialized_options = b'\232\305\210\036$\n\"envoy.type.matcher.MetadataMatcher'
  _globals['_METADATAMATCHER']._serialized_start=190
  _globals['_METADATAMATCHER']._serialized_end=539
  _globals['_METADATAMATCHER_PATHSEGMENT']._serialized_start=388
  _globals['_METADATAMATCHER_PATHSEGMENT']._serialized_end=496
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/compression/brotli/compressor/v3/brotli.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>envoy/extensions/compression/brotli/compressor/v3/brotli.proto\x12\x31\x65nvoy.extensions.compression.brotli.compressor.v3\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xcf\x03\n\x06\x42rotli\x12\x36\n\x07quality\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x0b\x12\x65\n\x0c\x65ncoder_mode\x18\x02 \x01(\x0e\x32\x45.envoy.extensions.compression.brotli.compressor.v3.Brotli.EncoderModeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12<\n\x0bwindow_bits\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\t\xfa\x42\x06*\x04\x18\x18(\n\x12\x41\n\x10input_block_bits\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\t\xfa\x42\x06*\x04\x18\x18(\x10\x12>\n\nchunk_size\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0c\xfa\x42\t*\x07\x18\x80\x80\x04(\x80 \x12(\n disable_literal_context_modeling\x18\x06 \x01(\x08\";\n\x0b\x45ncoderMode\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x0b\n\x07GENERIC\x10\x01\x12\x08\n\x04TEXT\x10\x02\x12\x08\n\x04\x46ONT\x10\x03\x42\xbf\x01\n?io.envoyproxy.envoy.extensions.compression.brotli.compressor.v3B\x0b\x42rotliProtoP\x01Zegithub.com/envoyproxy/go-control-plane/envoy/extensions/compression/brotli/compressor/v3;compressorv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.compression.brotli.compressor.v3.brotli_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n?io.envoyproxy.envoy.extensions.compression.brotli.compressor.v3B\013BrotliProtoP\001Zegithub.com/envoyproxy/go-control-plane/envoy/extensions/compression/brotli/compressor/v3;compressorv3\272\200\310\321\006\002\020\002'
  _BROTLI.fields_by_name['quality']._options = None
  _BROTLI.fields_by_name['quality']._serialized_options = b'\372B\004*\002\030\013'
  _BROTLI.fields_by_name['encoder_mode']._options = None
  _BROTLI.fields_by_name['encoder_mode']._serialized_options = b'\372B\005\202\001\002\020\001'
  _BROTLI.fields_by_name['window_bits']._options = None
  _BROTLI.fields_by_name['window_bits']._serialized_options = b'\372B\006*\004\030\030(\n'
  _BROTLI.fields_by_name['input_block_bits']._options = None
  _BROTLI.fields_by_name['input_block_bits']._serialized_options = b'\372B\006*\004\030\030(\020'
  _BROTLI.fields_by_name['chunk_size']._options = None
  _BROTLI.fields_by_name['chunk_size']._serialized_options = b'\372B\t*\007\030\200\200\004(\200 '
  _globals['_BROTLI']._serialized_start=206
  _globals['_BROTLI']._serialized_end=669
  _globals['_BROTLI_ENCODERMODE']._serialized_start=610
  _globals['_BROTLI_ENCODERMODE']._serialized_end=669
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/network/http_connection_manager/v2/http_connection_manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import config_source_pb2 as envoy_dot_api_dot_v2_dot_core_dot_config__source__pb2
from envoy.api.v2.core import protocol_pb2 as envoy_dot_api_dot_v2_dot_core_dot_protocol__pb2
from envoy.api.v2 import route_pb2 as envoy_dot_api_dot_v2_dot_route__pb2
from envoy.api.v2 import scoped_route_pb2 as envoy_dot_api_dot_v2_dot_scoped__route__pb2
from envoy.config.filter.accesslog.v2 import accesslog_pb2 as envoy_dot_config_dot_filter_dot_accesslog_dot_v2_dot_accesslog__pb2
from envoy.config.trace.v2 import http_tracer_pb2 as envoy_dot_config_dot_trace_dot_v2_dot_http__tracer__pb2
from envoy.type import percent_pb2 as envoy_dot_type_dot_percent__pb2
from envoy.type.tracing.v2 import custom_tag_pb2 as envoy_dot_type_dot_tracing_dot_v2_dot_custom__tag__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nTenvoy/config/filter/network/http_connection_manager/v2/http_connection_manager.proto\x12\x36\x65nvoy.config.filter.network.http_connection_manager.v2\x1a%envoy/api/v2/core/config_source.proto\x1a envoy/api/v2/core/protocol.proto\x1a\x18\x65nvoy/api/v2/route.proto\x1a\x1f\x65nvoy/api/v2/scoped_route.proto\x1a\x30\x65nvoy/config/filter/accesslog/v2/accesslog.proto\x1a\'envoy/config/trace/v2/http_tracer.proto\x1a\x18\x65nvoy/type/percent.proto\x1a&envoy/type/tracing/v2/custom_tag.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xff\x1c\n\x15HttpConnectionManager\x12u\n\ncodec_type\x18\x01 \x01(\x0e\x32W.envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.CodecTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x1c\n\x0bstat_prefix\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12J\n\x03rds\x18\x03 \x01(\x0b\x32;.envoy.config.filter.network.http_connection_manager.v2.RdsH\x00\x12\x38\n\x0croute_config\x18\x04 \x01(\x0b\x32 .envoy.api.v2.RouteConfigurationH\x00\x12]\n\rscoped_routes\x18\x1f \x01(\x0b\x32\x44.envoy.config.filter.network.http_connection_manager.v2.ScopedRoutesH\x00\x12X\n\x0chttp_filters\x18\x05 \x03(\x0b\x32\x42.envoy.config.filter.network.http_connection_manager.v2.HttpFilter\x12\x32\n\x0e\x61\x64\x64_user_agent\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x66\n\x07tracing\x18\x07 \x01(\x0b\x32U.envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.Tracing\x12L\n\x1c\x63ommon_http_protocol_options\x18# \x01(\x0b\x32&.envoy.api.v2.core.HttpProtocolOptions\x12\x46\n\x15http_protocol_options\x18\x08 \x01(\x0b\x32\'.envoy.api.v2.core.Http1ProtocolOptions\x12G\n\x16http2_protocol_options\x18\t \x01(\x0b\x32\'.envoy.api.v2.core.Http2ProtocolOptions\x12\x13\n\x0bserver_name\x18\n \x01(\t\x12\x98\x01\n\x1cserver_header_transformation\x18\" \x01(\x0e\x32h.envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.ServerHeaderTransformationB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12H\n\x16max_request_headers_kb\x18\x1d \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\n\xfa\x42\x07*\x05\x18\x80@ \x00\x12\x39\n\x0cidle_timeout\x18\x0b \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\x18\x01\xb8\xee\xf2\xd2\x05\x01\x12\x36\n\x13stream_idle_timeout\x18\x18 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x32\n\x0frequest_timeout\x18\x1c \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x30\n\rdrain_timeout\x18\x0c \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x38\n\x15\x64\x65layed_close_timeout\x18\x1a \x01(\x0b\x32\x19.google.protobuf.Duration\x12?\n\naccess_log\x18\r \x03(\x0b\x32+.envoy.config.filter.accesslog.v2.AccessLog\x12\x36\n\x12use_remote_address\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x1c\n\x14xff_num_trusted_hops\x18\x13 \x01(\r\x12\x84\x01\n\x17internal_address_config\x18\x19 \x01(\x0b\x32\x63.envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.InternalAddressConfig\x12\x17\n\x0fskip_xff_append\x18\x15 \x01(\x08\x12\x0b\n\x03via\x18\x16 \x01(\t\x12\x37\n\x13generate_request_id\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12$\n\x1cpreserve_external_request_id\x18  \x01(\x08\x12\x95\x01\n\x1b\x66orward_client_cert_details\x18\x10 \x01(\x0e\x32\x66.envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.ForwardClientCertDetailsB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x92\x01\n\x1fset_current_client_cert_details\x18\x11 \x01(\x0b\x32i.envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.SetCurrentClientCertDetails\x12\x1a\n\x12proxy_100_continue\x18\x12 \x01(\x08\x12\x39\n1represent_ipv4_remote_address_as_ipv4_mapped_ipv6\x18\x14 \x01(\x08\x12t\n\x0fupgrade_configs\x18\x17 \x03(\x0b\x32[.envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.UpgradeConfig\x12\x32\n\x0enormalize_path\x18\x1e \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x15\n\rmerge_slashes\x18! \x01(\x08\x12h\n\x14request_id_extension\x18$ \x01(\x0b\x32J.envoy.config.filter.network.http_connection_manager.v2.RequestIDExtension\x1a\xae\x04\n\x07Tracing\x12\x8d\x01\n\x0eoperation_name\x18\x01 \x01(\x0e\x32\x63.envoy.config.filter.network.http_connection_manager.v2.HttpConnectionManager.Tracing.OperationNameB\x10\x18\x01\xfa\x42\x05\x82\x01\x02\x10\x01\xb8\xee\xf2\xd2\x05\x01\x12$\n\x18request_headers_for_tags\x18\x02 \x03(\tB\x02\x18\x01\x12,\n\x0f\x63lient_sampling\x18\x03 \x01(\x0b\x32\x13.envoy.type.Percent\x12,\n\x0frandom_sampling\x18\x04 \x01(\x0b\x32\x13.envoy.type.Percent\x12-\n\x10overall_sampling\x18\x05 \x01(\x0b\x32\x13.envoy.type.Percent\x12\x0f\n\x07verbose\x18\x06 \x01(\x08\x12\x39\n\x13max_path_tag_length\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x35\n\x0b\x63ustom_tags\x18\x08 \x03(\x0b\x32 .envoy.type.tracing.v2.CustomTag\x12\x35\n\x08provider\x18\t \x01(\x0b\x32#.envoy.config.trace.v2.Tracing.Http\"(\n\rOperationName\x12\x0b\n\x07INGRESS\x10\x00\x12\n\n\x06\x45GRESS\x10\x01\x1a-\n\x15InternalAddressConfig\x12\x14\n\x0cunix_sockets\x18\x01 \x01(\x08\x1a\x87\x01\n\x1bSetCurrentClientCertDetails\x12+\n\x07subject\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x0c\n\x04\x63\x65rt\x18\x03 \x01(\x08\x12\r\n\x05\x63hain\x18\x06 \x01(\x08\x12\x0b\n\x03\x64ns\x18\x04 \x01(\x08\x12\x0b\n\x03uri\x18\x05 \x01(\x08J\x04\x08\x02\x10\x03\x1a\xa7\x01\n\rUpgradeConfig\x12\x14\n\x0cupgrade_type\x18\x01 \x01(\t\x12S\n\x07\x66ilters\x18\x02 \x03(\x0b\x32\x42.envoy.config.filter.network.http_connection_manager.v2.HttpFilter\x12+\n\x07\x65nabled\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"6\n\tCodecType\x12\x08\n\x04\x41UTO\x10\x00\x12\t\n\x05HTTP1\x10\x01\x12\t\n\x05HTTP2\x10\x02\x12\t\n\x05HTTP3\x10\x03\"S\n\x1aServerHeaderTransformation\x12\r\n\tOVERWRITE\x10\x00\x12\x14\n\x10\x41PPEND_IF_ABSENT\x10\x01\x12\x10\n\x0cPASS_THROUGH\x10\x02\"y\n\x18\x46orwardClientCertDetails\x12\x0c\n\x08SANITIZE\x10\x00\x12\x10\n\x0c\x46ORWARD_ONLY\x10\x01\x12\x12\n\x0e\x41PPEND_FORWARD\x10\x02\x12\x10\n\x0cSANITIZE_SET\x10\x03\x12\x17\n\x13\x41LWAYS_FORWARD_ONLY\x10\x04\x42\x16\n\x0froute_specifier\x12\x03\xf8\x42\x01J\x04\x08\x1b\x10\x1c\"k\n\x03Rds\x12@\n\rconfig_source\x18\x01 \x01(\x0b\x32\x1f.envoy.api.v2.core.ConfigSourceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\"\n\x11route_config_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\"v\n\x1dScopedRouteConfigurationsList\x12U\n\x1bscoped_route_configurations\x18\x01 \x03(\x0b\x32&.envoy.api.v2.ScopedRouteConfigurationB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\"\xf8\x08\n\x0cScopedRoutes\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12y\n\x11scope_key_builder\x18\x02 \x01(\x0b\x32T.envoy.config.filter.network.http_connection_manager.v2.ScopedRoutes.ScopeKeyBuilderB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x44\n\x11rds_config_source\x18\x03 \x01(\x0b\x32\x1f.envoy.api.v2.core.ConfigSourceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x81\x01\n scoped_route_configurations_list\x18\x04 \x01(\x0b\x32U.envoy.config.filter.network.http_connection_manager.v2.ScopedRouteConfigurationsListH\x00\x12W\n\nscoped_rds\x18\x05 \x01(\x0b\x32\x41.envoy.config.filter.network.http_connection_manager.v2.ScopedRdsH\x00\x1a\x99\x05\n\x0fScopeKeyBuilder\x12\x81\x01\n\tfragments\x18\x01 \x03(\x0b\x32\x64.envoy.config.filter.network.http_connection_manager.v2.ScopedRoutes.ScopeKeyBuilder.FragmentBuilderB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\x81\x04\n\x0f\x46ragmentBuilder\x12\x9b\x01\n\x16header_value_extractor\x18\x01 \x01(\x0b\x32y.envoy.config.filter.network.http_connection_manager.v2.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.HeaderValueExtractorH\x00\x1a\xc2\x02\n\x14HeaderValueExtractor\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x19\n\x11\x65lement_separator\x18\x02 \x01(\t\x12\x0f\n\x05index\x18\x03 \x01(\rH\x00\x12\x97\x01\n\x07\x65lement\x18\x04 \x01(\x0b\x32\x83\x01.envoy.config.filter.network.http_connection_manager.v2.ScopedRoutes.ScopeKeyBuilder.FragmentBuilder.HeaderValueExtractor.KvElementH\x00\x1a=\n\tKvElement\x12\x1a\n\tseparator\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x14\n\x03key\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x42\x0e\n\x0c\x65xtract_typeB\x0b\n\x04type\x12\x03\xf8\x42\x01\x42\x17\n\x10\x63onfig_specifier\x12\x03\xf8\x42\x01\"X\n\tScopedRds\x12K\n\x18scoped_rds_config_source\x18\x01 \x01(\x0b\x32\x1f.envoy.api.v2.core.ConfigSourceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\x95\x01\n\nHttpFilter\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12-\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x02\x18\x01H\x00\x12,\n\x0ctyped_config\x18\x04 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\r\n\x0b\x63onfig_typeJ\x04\x08\x03\x10\x04\"@\n\x12RequestIDExtension\x12*\n\x0ctyped_config\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyB\xa8\x02\nDio.envoyproxy.envoy.config.filter.network.http_connection_manager.v2B\x1aHttpConnectionManagerProtoP\x01Zwgithub.com/envoyproxy/go-control-plane/envoy/config/filter/network/http_connection_manager/v2;http_connection_managerv2\xf2\x98\xfe\x8f\x05=\x12;envoy.extensions.filters.network.http_connection_manager.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.network.http_connection_manager.v2.http_connection_manager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nDio.envoyproxy.envoy.config.filter.network.http_connection_manager.v2B\032HttpConnectionManagerProtoP\001Zwgithub.com/envoyproxy/go-control-plane/envoy/config/filter/network/http_connection_manager/v2;http_connection_managerv2\362\230\376\217\005=\022;envoy.extensions.filters.network.http_connection_manager.v3\272\200\310\321\006\002\020\001'
  _HTTPCONNECTIONMANAGER_TRACING.fields_by_name['operation_name']._options = None
  _HTTPCONNECTIONMANAGER_TRACING.fields_by_name['operation_name']._serialized_options = b'\030\001\372B\005\202\001\002\020\001\270\356\362\322\005\001'
  _HTTPCONNECTIONMANAGER_TRACING.fields_by_name['request_headers_for_tags']._options = None
  _HTTPCONNECTIONMANAGER_TRACING.fields_by_name['request_headers_for_tags']._serialized_options = b'\030\001'
  _HTTPCONNECTIONMANAGER.oneofs_by_name['route_specifier']._options = None
  _HTTPCONNECTIONMANAGER.oneofs_by_name['route_specifier']._serialized_options = b'\370B\001'
  _HTTPCONNECTIONMANAGER.fields_by_name['codec_type']._options = None
  _HTTPCONNECTIONMANAGER.fields_by_name['codec_type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _HTTPCONNECTIONMANAGER.fields_by_name['stat_prefix']._options = None
  _HTTPCONNECTIONMANAGER.fields_by_name['stat_prefix']._serialized_options = b'\372B\004r\002 \001'
  _HTTPCONNECTIONMANAGER.fields_by_name['server_header_transformation']._options = None
  _HTTPCONNECTIONMANAGER.fields_by_name['server_header_transformation']._serialized_options = b'\372B\005\202\001\002\020\001'
  _HTTPCONNECTIONMANAGER.fields_by_name['max_request_headers_kb']._options = None
  _HTTPCONNECTIONMANAGER.fields_by_name['max_request_headers_kb']._serialized_options = b'\372B\007*\005\030\200@ \000'
  _HTTPCONNECTIONMANAGER.fields_by_name['idle_timeout']._options = None
  _HTTPCONNECTIONMANAGER.fields_by_name['idle_timeout']._serialized_options = b'\030\001\270\356\362\322\005\001'
  _HTTPCONNECTIONMANAGER.fields_by_name['forward_client_cert_details']._options = None
  _HTTPCONNECTIONMANAGER.fields_by_name['forward_client_cert_details']._serialized_options = b'\372B\005\202\001\002\020\001'
  _RDS.fields_by_name['config_source']._options = None
  _RDS.fields_by_name['config_source']._serialized_options = b'\372B\005\212\001\002\020\001'
  _RDS.fields_by_name['route_config_name']._options = None
  _RDS.fields_by_name['route_config_name']._serialized_options = b'\372B\004r\002 \001'
  _SCOPEDROUTECONFIGURATIONSLIST.fields_by_name['scoped_route_configurations']._options = None
  _SCOPEDROUTECONFIGURATIONSLIST.fields_by_name['scoped_route_configurations']._serialized_options = b'\372B\005\222\001\002\010\001'
  _SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR_KVELEMENT.fields_by_name['separator']._options = None
  _SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR_KVELEMENT.fields_by_name['separator']._serialized_options = b'\372B\004r\002 \001'
  _SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR_KVELEMENT.fields_by_name['key']._options = None
  _SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR_KVELEMENT.fields_by_name['key']._serialized_options = b'\372B\004r\002 \001'
  _SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR.fields_by_name['name']._options = None
  _SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR.fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER.oneofs_by_name['type']._options = None
  _SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER.oneofs_by_name['type']._serialized_options = b'\370B\001'
  _SCOPEDROUTES_SCOPEKEYBUILDER.fields_by_name['fragments']._options = None
  _SCOPEDROUTES_SCOPEKEYBUILDER.fields_by_name['fragments']._serialized_options = b'\372B\005\222\001\002\010\001'
  _SCOPEDROUTES.oneofs_by_name['config_specifier']._options = None
  _SCOPEDROUTES.oneofs_by_name['config_specifier']._serialized_options = b'\370B\001'
  _SCOPEDROUTES.fields_by_name['name']._options = None
  _SCOPEDROUTES.fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _SCOPEDROUTES.fields_by_name['scope_key_builder']._options = None
  _SCOPEDROUTES.fields_by_name['scope_key_builder']._serialized_options = b'\372B\005\212\001\002\020\001'
  _SCOPEDROUTES.fields_by_name['rds_config_source']._options = None
  _SCOPEDROUTES.fields_by_name['rds_config_source']._serialized_options = b'\372B\005\212\001\002\020\001'
  _SCOPEDRDS.fields_by_name['scoped_rds_config_source']._options = None
  _SCOPEDRDS.fields_by_name['scoped_rds_config_source']._serialized_options = b'\372B\005\212\001\002\020\001'
  _HTTPFILTER.fields_by_name['name']._options = None
  _HTTPFILTER.fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _HTTPFILTER.fields_by_name['config']._options = None
  _HTTPFILTER.fields_by_name['config']._serialized_options = b'\030\001'
  _globals['_HTTPCONNECTIONMANAGER']._serialized_start=680
  _globals['_HTTPCONNECTIONMANAGER']._serialized_end=4391
  _globals['_HTTPCONNECTIONMANAGER_TRACING']._serialized_start=3184
  _globals['_HTTPCONNECTIONMANAGER_TRACING']._serialized_end=3742
  _globals['_HTTPCONNECTIONMANAGER_TRACING_OPERATIONNAME']._serialized_start=3702
  _globals['_HTTPCONNECTIONMANAGER_TRACING_OPERATIONNAME']._serialized_end=3742
  _globals['_HTTPCONNECTIONMANAGER_INTERNALADDRESSCONFIG']._serialized_start=3744
  _globals['_HTTPCONNECTIONMANAGER_INTERNALADDRESSCONFIG']._serialized_end=3789
  _globals['_HTTPCONNECTIONMANAGER_SETCURRENTCLIENTCERTDETAILS']._serialized_start=3792
  _globals['_HTTPCONNECTIONMANAGER_SETCURRENTCLIENTCERTDETAILS']._serialized_end=3927
  _globals['_HTTPCONNECTIONMANAGER_UPGRADECONFIG']._serialized_start=3930
  _globals['_HTTPCONNECTIONMANAGER_UPGRADECONFIG']._serialized_end=4097
  _globals['_HTTPCONNECTIONMANAGER_CODECTYPE']._serialized_start=4099
  _globals['_HTTPCONNECTIONMANAGER_CODECTYPE']._serialized_end=4153
  _globals['_HTTPCONNECTIONMANAGER_SERVERHEADERTRANSFORMATION']._serialized_start=4155
  _globals['_HTTPCONNECTIONMANAGER_SERVERHEADERTRANSFORMATION']._serialized_end=4238
  _globals['_HTTPCONNECTIONMANAGER_FORWARDCLIENTCERTDETAILS']._serialized_start=4240
  _globals['_HTTPCONNECTIONMANAGER_FORWARDCLIENTCERTDETAILS']._serialized_end=4361
  _globals['_RDS']._serialized_start=4393
  _globals['_RDS']._serialized_end=4500
  _globals['_SCOPEDROUTECONFIGURATIONSLIST']._serialized_start=4502
  _globals['_SCOPEDROUTECONFIGURATIONSLIST']._serialized_end=4620
  _globals['_SCOPEDROUTES']._serialized_start=4623
  _globals['_SCOPEDROUTES']._serialized_end=5767
  _globals['_SCOPEDROUTES_SCOPEKEYBUILDER']._serialized_start=5077
  _globals['_SCOPEDROUTES_SCOPEKEYBUILDER']._serialized_end=5742
  _globals['_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER']._serialized_start=5229
  _globals['_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER']._serialized_end=5742
  _globals['_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR']._serialized_start=5407
  _globals['_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR']._serialized_end=5729
  _globals['_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR_KVELEMENT']._serialized_start=5652
  _globals['_SCOPEDROUTES_SCOPEKEYBUILDER_FRAGMENTBUILDER_HEADERVALUEEXTRACTOR_KVELEMENT']._serialized_end=5713
  _globals['_SCOPEDRDS']._serialized_start=5769
  _globals['_SCOPEDRDS']._serialized_end=5857
  _globals['_HTTPFILTER']._serialized_start=5860
  _globals['_HTTPFILTER']._serialized_end=6009
  _globals['_REQUESTIDEXTENSION']._serialized_start=6011
  _globals['_REQUESTIDEXTENSION']._serialized_end=6075
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/ratelimit/ratelimit.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&envoy/api/v2/ratelimit/ratelimit.proto\x12\x16\x65nvoy.api.v2.ratelimit\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x9a\x01\n\x13RateLimitDescriptor\x12L\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x31.envoy.api.v2.ratelimit.RateLimitDescriptor.EntryB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\x35\n\x05\x45ntry\x12\x14\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x16\n\x05value\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x42\xab\x01\n$io.envoyproxy.envoy.api.v2.ratelimitB\x0eRatelimitProtoP\x01Z=github.com/envoyproxy/go-control-plane/envoy/api/v2/ratelimit\xf2\x98\xfe\x8f\x05&\x12$envoy.extensions.common.ratelimit.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.ratelimit.ratelimit_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$io.envoyproxy.envoy.api.v2.ratelimitB\016RatelimitProtoP\001Z=github.com/envoyproxy/go-control-plane/envoy/api/v2/ratelimit\362\230\376\217\005&\022$envoy.extensions.common.ratelimit.v3\272\200\310\321\006\002\020\001'
  _RATELIMITDESCRIPTOR_ENTRY.fields_by_name['key']._options = None
  _RATELIMITDESCRIPTOR_ENTRY.fields_by_name['key']._serialized_options = b'\372B\004r\002 \001'
  _RATELIMITDESCRIPTOR_ENTRY.fields_by_name['value']._options = None
  _RATELIMITDESCRIPTOR_ENTRY.fields_by_name['value']._serialized_options = b'\372B\004r\002 \001'
  _RATELIMITDESCRIPTOR.fields_by_name['entries']._options = None
  _RATELIMITDESCRIPTOR.fields_by_name['entries']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_RATELIMITDESCRIPTOR']._serialized_start=155
  _globals['_RATELIMITDESCRIPTOR']._serialized_end=309
  _globals['_RATELIMITDESCRIPTOR_ENTRY']._serialized_start=256
  _globals['_RATELIMITDESCRIPTOR_ENTRY']._serialized_end=309
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/cluster/filter.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!envoy/api/v2/cluster/filter.proto\x12\x14\x65nvoy.api.v2.cluster\x1a\x19google/protobuf/any.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"K\n\x06\x46ilter\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12*\n\x0ctyped_config\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyB\xcc\x01\n\"io.envoyproxy.envoy.api.v2.clusterB\x0b\x46ilterProtoP\x01Z;github.com/envoyproxy/go-control-plane/envoy/api/v2/cluster\xaa\x02\x16\x45nvoy.Api.V2.ClusterNS\xea\x02\x19\x45nvoy::Api::V2::ClusterNS\xf2\x98\xfe\x8f\x05\x19\x12\x17\x65nvoy.config.cluster.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.cluster.filter_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"io.envoyproxy.envoy.api.v2.clusterB\013FilterProtoP\001Z;github.com/envoyproxy/go-control-plane/envoy/api/v2/cluster\252\002\026Envoy.Api.V2.ClusterNS\352\002\031Envoy::Api::V2::ClusterNS\362\230\376\217\005\031\022\027envoy.config.cluster.v3\272\200\310\321\006\002\020\001'
  _FILTER.fields_by_name['name']._options = None
  _FILTER.fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _globals['_FILTER']._serialized_start=174
  _globals['_FILTER']._serialized_end=249
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/transport_sockets/tls/v3/cert.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.transport_sockets.tls.v3 import common_pb2 as envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_common__pb2
from envoy.extensions.transport_sockets.tls.v3 import secret_pb2 as envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_secret__pb2
from envoy.extensions.transport_sockets.tls.v3 import tls_pb2 as envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_tls__pb2

from envoy.extensions.transport_sockets.tls.v3.common_pb2 import *
from envoy.extensions.transport_sockets.tls.v3.secret_pb2 import *
from envoy.extensions.transport_sockets.tls.v3.tls_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4envoy/extensions/transport_sockets/tls/v3/cert.proto\x12)envoy.extensions.transport_sockets.tls.v3\x1a\x36\x65nvoy/extensions/transport_sockets/tls/v3/common.proto\x1a\x36\x65nvoy/extensions/transport_sockets/tls/v3/secret.proto\x1a\x33\x65nvoy/extensions/transport_sockets/tls/v3/tls.protoB\x9e\x01\n7io.envoyproxy.envoy.extensions.transport_sockets.tls.v3B\tCertProtoP\x01ZVgithub.com/envoyproxy/go-control-plane/envoy/extensions/transport_sockets/tls/v3;tlsv3P\x00P\x01P\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.transport_sockets.tls.v3.cert_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7io.envoyproxy.envoy.extensions.transport_sockets.tls.v3B\tCertProtoP\001ZVgithub.com/envoyproxy/go-control-plane/envoy/extensions/transport_sockets/tls/v3;tlsv3'
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/metadata/v2/metadata.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%envoy/type/metadata/v2/metadata.proto\x12\x16\x65nvoy.type.metadata.v2\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xa3\x01\n\x0bMetadataKey\x12\x14\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12G\n\x04path\x18\x02 \x03(\x0b\x32/.envoy.type.metadata.v2.MetadataKey.PathSegmentB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\x35\n\x0bPathSegment\x12\x16\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01H\x00\x42\x0e\n\x07segment\x12\x03\xf8\x42\x01\"\xbc\x02\n\x0cMetadataKind\x12?\n\x07request\x18\x01 \x01(\x0b\x32,.envoy.type.metadata.v2.MetadataKind.RequestH\x00\x12;\n\x05route\x18\x02 \x01(\x0b\x32*.envoy.type.metadata.v2.MetadataKind.RouteH\x00\x12?\n\x07\x63luster\x18\x03 \x01(\x0b\x32,.envoy.type.metadata.v2.MetadataKind.ClusterH\x00\x12\x39\n\x04host\x18\x04 \x01(\x0b\x32).envoy.type.metadata.v2.MetadataKind.HostH\x00\x1a\t\n\x07Request\x1a\x07\n\x05Route\x1a\t\n\x07\x43luster\x1a\x06\n\x04HostB\x0b\n\x04kind\x12\x03\xf8\x42\x01\x42\xa7\x01\n$io.envoyproxy.envoy.type.metadata.v2B\rMetadataProtoP\x01ZHgithub.com/envoyproxy/go-control-plane/envoy/type/metadata/v2;metadatav2\xf2\x98\xfe\x8f\x05\x18\x12\x16\x65nvoy.type.metadata.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.type.metadata.v2.metadata_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$io.envoyproxy.envoy.type.metadata.v2B\rMetadataProtoP\001ZHgithub.com/envoyproxy/go-control-plane/envoy/type/metadata/v2;metadatav2\362\230\376\217\005\030\022\026envoy.type.metadata.v3\272\200\310\321\006\002\020\001'
  _METADATAKEY_PATHSEGMENT.oneofs_by_name['segment']._options = None
  _METADATAKEY_PATHSEGMENT.oneofs_by_name['segment']._serialized_options = b'\370B\001'
  _METADATAKEY_PATHSEGMENT.fields_by_name['key']._options = None
  _METADATAKEY_PATHSEGMENT.fields_by_name['key']._serialized_options = b'\372B\004r\002 \001'
  _METADATAKEY.fields_by_name['key']._options = None
  _METADATAKEY.fields_by_name['key']._serialized_options = b'\372B\004r\002 \001'
  _METADATAKEY.fields_by_name['path']._options = None
  _METADATAKEY.fields_by_name['path']._serialized_options = b'\372B\005\222\001\002\010\001'
  _METADATAKIND.oneofs_by_name['kind']._options = None
  _METADATAKIND.oneofs_by_name['kind']._serialized_options = b'\370B\001'
  _globals['_METADATAKEY']._serialized_start=154
  _globals['_METADATAKEY']._serialized_end=317
  _globals['_METADATAKEY_PATHSEGMENT']._serialized_start=264
  _globals['_METADATAKEY_PATHSEGMENT']._serialized_end=317
  _globals['_METADATAKIND']._serialized_start=320
  _globals['_METADATAKIND']._serialized_end=636
  _globals['_METADATAKIND_REQUEST']._serialized_start=586
  _globals['_METADATAKIND_REQUEST']._serialized_end=595
  _globals['_METADATAKIND_ROUTE']._serialized_start=597
  _globals['_METADATAKIND_ROUTE']._serialized_end=604
  _globals['_METADATAKIND_CLUSTER']._serialized_start=606
  _globals['_METADATAKIND_CLUSTER']._serialized_end=615
  _globals['_METADATAKIND_HOST']._serialized_start=617
  _globals['_METADATAKIND_HOST']._serialized_end=623
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/core/v3/socket_option.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(envoy/config/core/v3/socket_option.proto\x12\x14\x65nvoy.config.core.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xb0\x02\n\x0cSocketOption\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\r\n\x05level\x18\x02 \x01(\x03\x12\x0c\n\x04name\x18\x03 \x01(\x03\x12\x13\n\tint_value\x18\x04 \x01(\x03H\x00\x12\x13\n\tbuf_value\x18\x05 \x01(\x0cH\x00\x12G\n\x05state\x18\x06 \x01(\x0e\x32..envoy.config.core.v3.SocketOption.SocketStateB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"F\n\x0bSocketState\x12\x11\n\rSTATE_PREBIND\x10\x00\x12\x0f\n\x0bSTATE_BOUND\x10\x01\x12\x13\n\x0fSTATE_LISTENING\x10\x02:%\x9a\xc5\x88\x1e \n\x1e\x65nvoy.api.v2.core.SocketOptionB\x0c\n\x05value\x12\x03\xf8\x42\x01\"S\n\x15SocketOptionsOverride\x12:\n\x0esocket_options\x18\x01 \x03(\x0b\x32\".envoy.config.core.v3.SocketOptionB\x85\x01\n\"io.envoyproxy.envoy.config.core.v3B\x11SocketOptionProtoP\x01ZBgithub.com/envoyproxy/go-control-plane/envoy/config/core/v3;corev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.core.v3.socket_option_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"io.envoyproxy.envoy.config.core.v3B\021SocketOptionProtoP\001ZBgithub.com/envoyproxy/go-control-plane/envoy/config/core/v3;corev3\272\200\310\321\006\002\020\002'
  _SOCKETOPTION.oneofs_by_name['value']._options = None
  _SOCKETOPTION.oneofs_by_name['value']._serialized_options = b'\370B\001'
  _SOCKETOPTION.fields_by_name['state']._options = None
  _SOCKETOPTION.fields_by_name['state']._serialized_options = b'\372B\005\202\001\002\020\001'
  _SOCKETOPTION._options = None
  _SOCKETOPTION._serialized_options = b'\232\305\210\036 \n\036envoy.api.v2.core.SocketOption'
  _globals['_SOCKETOPTION']._serialized_start=158
  _globals['_SOCKETOPTION']._serialized_end=462
  _globals['_SOCKETOPTION_SOCKETSTATE']._serialized_start=339
  _globals['_SOCKETOPTION_SOCKETSTATE']._serialized_end=409
  _globals['_SOCKETOPTIONSOVERRIDE']._serialized_start=464
  _globals['_SOCKETOPTIONSOVERRIDE']._serialized_end=547
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/launch_stage.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dgoogle/api/launch_stage.proto\x12\ngoogle.api*\x8c\x01\n\x0bLaunchStage\x12\x1c\n\x18LAUNCH_STAGE_UNSPECIFIED\x10\x00\x12\x11\n\rUNIMPLEMENTED\x10\x06\x12\r\n\tPRELAUNCH\x10\x07\x12\x10\n\x0c\x45\x41RLY_ACCESS\x10\x01\x12\t\n\x05\x41LPHA\x10\x02\x12\x08\n\x04\x42\x45TA\x10\x03\x12\x06\n\x02GA\x10\x04\x12\x0e\n\nDEPRECATED\x10\x05\x42Z\n\x0e\x63om.google.apiB\x10LaunchStageProtoP\x01Z-google.golang.org/genproto/googleapis/api;api\xa2\x02\x04GAPIb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.launch_stage_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\016com.google.apiB\020LaunchStageProtoP\001Z-google.golang.org/genproto/googleapis/api;api\242\002\004GAPI'
  _globals['_LAUNCHSTAGE']._serialized_start=46
  _globals['_LAUNCHSTAGE']._serialized_end=186
# @@protoc_insertion_point(module_scope)
